@@ -41,9 +41,10 @@ gint get_Id_from_address (gint chipnumber, gint addr_chipfeature,
 
 /**
  * Write the configuration, e.g., when exiting the plugin.
+ * @param ptr_panelplugin: pointer to panel plugin structure
  * @param ptr_sensors: pointer to sensors structure
  */
-void sensors_write_config (t_sensors *ptr_sensors);
+void sensors_write_config (XfcePanelPlugin *ptr_panelplugin,t_sensors *ptr_sensors);
 
 
 /**
