@@ -74,7 +74,7 @@ get_Id_from_address (gint idx_chip, gint addr_chipfeature, t_sensors *ptr_sensor
 
 /* -------------------------------------------------------------------------- */
 void
-sensors_write_config (t_sensors *ptr_sensors)
+sensors_write_config (XfcePanelPlugin *plugin,t_sensors *ptr_sensors)
 {
     XfceRc *ptr_xfcerc;
     gchar *str_file, *str_tmp, str_chip[8], str_feature[20];
@@ -240,7 +240,7 @@ sensors_read_general_config (XfceRc *ptr_xfceresources, t_sensors *ptr_sensors)
             font = g_strdup(str_value); // in tacho.h for the tachometers
         }
         else if (font==NULL)
-            font = g_strdup("Sans 12");
+            font = g_strdup("Sans 11");
 
         ptr_sensors->val_fontsize = xfce_rc_read_int_entry (ptr_xfceresources,
                                                  "val_fontsize", 2);
@@ -284,7 +284,6 @@ sensors_read_general_config (XfceRc *ptr_xfceresources, t_sensors *ptr_sensors)
 void
 sensors_read_preliminary_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
 {
-    gchar *str_file;
     XfceRc *ptr_xfceresource;
 
     TRACE ("enters sensors_read_preliminary_config");
@@ -293,10 +292,9 @@ sensors_read_preliminary_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *pt
     {
         g_return_if_fail(ptr_sensors!=NULL);
 
-        if ((str_file = ptr_sensors->plugin_config_file))
+        if ((ptr_sensors->plugin_config_file))
         {
-            ptr_xfceresource = xfce_rc_simple_open (str_file, TRUE);
-            g_free (str_file);
+            ptr_xfceresource = xfce_rc_simple_open (ptr_sensors->plugin_config_file, TRUE);
 
             if (ptr_xfceresource && xfce_rc_has_group (ptr_xfceresource, "General") ) {
                 xfce_rc_set_group (ptr_xfceresource, "General");
@@ -317,7 +315,6 @@ void
 sensors_read_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
 {
     const gchar *str_value;
-    gchar *str_file;
     XfceRc *ptr_xfceresource;
     gint idx_chip, idx_feature, idx_chiptmp;
     gchar str_rcchip[8], str_feature[20];
@@ -332,11 +329,10 @@ sensors_read_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
 
     g_return_if_fail(ptr_sensors!=NULL);
 
-    if (!(str_file = ptr_sensors->plugin_config_file))
+    if (!(ptr_sensors->plugin_config_file))
         return;
 
-    ptr_xfceresource = xfce_rc_simple_open (str_file, TRUE);
-    g_free (str_file);
+    ptr_xfceresource = xfce_rc_simple_open (ptr_sensors->plugin_config_file, TRUE);
 
     if (!ptr_xfceresource)
         return;
@@ -403,25 +399,22 @@ sensors_read_config (XfcePanelPlugin *ptr_panelplugin, t_sensors *ptr_sensors)
                         else if ((str_value = xfce_rc_read_entry (ptr_xfceresource, "DeviceName", NULL))
                             && *str_value) {
                             if (ptr_chipfeature->devicename)
-                                free (ptr_chipfeature->devicename);
+                                g_free (ptr_chipfeature->devicename);
                             ptr_chipfeature->devicename = g_strdup(str_value);
-                            /* g_free (str_value); */
                         }
 
                         if ((str_value = xfce_rc_read_entry (ptr_xfceresource, "Name", NULL))
                                 && *str_value) {
                             if (ptr_chipfeature->name)
-                                free (ptr_chipfeature->name);
+                                g_free (ptr_chipfeature->name);
                             ptr_chipfeature->name = g_strdup (str_value);
-                            /* g_free (str_value); */
                         }
 
                         if ((str_value = xfce_rc_read_entry (ptr_xfceresource, "Color", NULL))
                                 && *str_value) {
                             if (ptr_chipfeature->color)
-                                free (ptr_chipfeature->color);
+                                g_free (ptr_chipfeature->color);
                             ptr_chipfeature->color = g_strdup (str_value);
-                            /* g_free (str_value); */
                         }
 
                         ptr_chipfeature->show =
