@@ -1,5 +1,6 @@
-/* $Id$ */
-/*  Copyright 2004-2010 Fabian Nowak (timystery@arcor.de)
+/* File: hddtemp.c
+ *
+ *  Copyright 2004-2017 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -72,105 +73,109 @@
 void notification_suppress_messages (NotifyNotification *n, gchar *action, gpointer *data);
 #endif
 
-void quick_message_notify (gchar *message);
-void quick_message (gchar *message);
-void quick_message_dialog (gchar *message);
-gboolean quick_message_with_checkbox (gchar *message, gchar *checkboxtext);
+void quick_message_notify (gchar *str_message);
+void quick_message (gchar *str_message);
+void quick_message_dialog (gchar *str_message);
+gboolean quick_message_with_checkbox (gchar *str_message, gchar *str_checkboxtext);
 
-void read_disks_netcat (t_chip *chip);
-void read_disks_linux26 (t_chip *chip);
-int get_hddtemp_d_str (char *buffer, size_t bufsize);
-void read_disks_fallback (t_chip *chip);
-void remove_unmonitored_drives (t_chip *chip, gboolean *suppressmessage);
-void populate_detected_drives (t_chip *chip);
+void read_disks_netcat (t_chip *ptr_chip);
+void read_disks_linux26 (t_chip *ptr_chip);
+int get_hddtemp_d_str (char *str_buffer, size_t siz_buffer);
+void read_disks_fallback (t_chip *ptr_chip);
+void remove_unmonitored_drives (t_chip *ptr_chip, gboolean *ptr_suppressmessage);
+void populate_detected_drives (t_chip *ptr_chip);
 
+
+/* -------------------------------------------------------------------------- */
 #if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
 void
-notification_suppress_messages (NotifyNotification *n, gchar *action, gpointer *data)
+notification_suppress_messages (NotifyNotification *ptr_notification, gchar *str_action, gpointer *ptr_data)
 {
-    if (strcmp(action, "confirmed")!=0)
+    if (strcmp(str_action, "confirmed")!=0)
         return;
 
     /* FIXME: Use channels or propagate private object or use static global variable */
 }
 
-void
-quick_message_notify (gchar *message)
-{
-    NotifyNotification *nn;
-    gchar *summary, *body, *icon;
-    GError *error = NULL;
 
-    summary = "Hddtemp Information";
-    body = message;
-    icon = "xfce-sensors";
+/* -------------------------------------------------------------------------- */
+void
+quick_message_notify (gchar *str_message)
+{
+    NotifyNotification *ptr_notification;
+    const gchar *str_summary, *str_icon;
+    GError *ptr_error = NULL;
+
+    str_summary = "Hddtemp Information";
+    str_icon = "xfce-sensors";
 
     if (!notify_is_initted())
         notify_init(PACKAGE); /* NOTIFY_APPNAME */
 
 #ifdef HAVE_LIBNOTIFY7
-    nn = notify_notification_new (summary, body, icon);
+    ptr_notification = notify_notification_new (str_summary, str_message, str_icon);
 #elif HAVE_LIBNOTIFY4
-    nn = notify_notification_new (summary, body, icon, NULL);
+    ptr_notification = notify_notification_new (str_summary, str_message, str_icon, NULL);
 #endif
     /* FIXME: Use channels or propagate private object or use static global variable */
-    //notify_notification_add_action (nn,
+    //notify_notification_add_action (ptr_notification,
                             //"confirmed",
                             //_("Don't show this message again"),
                             //(NotifyActionCallback) notification_suppress_messages,
                             //NULL);
-    notify_notification_show(nn, &error);
+    notify_notification_show(ptr_notification, &ptr_error);
 }
 #else
+/* -------------------------------------------------------------------------- */
 void
-quick_message_dialog (gchar *message)
+quick_message_dialog (gchar *str_message)
 {
-
-    GtkWidget *dialog;  /*, *label; */
+    GtkWidget *ptr_dialog;
 
     TRACE ("enters quick_message");
 
-    dialog = gtk_message_dialog_new (NULL,
+    ptr_dialog = gtk_message_dialog_new (NULL,
                                   GTK_DIALOG_DESTROY_WITH_PARENT,
                                   GTK_MESSAGE_INFO,
                                   GTK_BUTTONS_CLOSE,
                                   message, NULL);
 
     g_signal_connect_swapped (dialog, "response",
-                             G_CALLBACK (gtk_widget_destroy), dialog);
+                             G_CALLBACK (gtk_widget_destroy), ptr_dialog);
 
-    gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_dialog_run(GTK_DIALOG(ptr_dialog));
 
     TRACE ("leaves quick_message");
 }
 
 
+/* -------------------------------------------------------------------------- */
 gboolean
-quick_message_with_checkbox (gchar *message, gchar *checkboxtext) {
-
-    GtkWidget *dialog, *checkbox;  /*, *label; */
+quick_message_with_checkbox (gchar *str_message, gchar *str_checkboxtext)
+{
+    GtkWidget *ptr_dialog, *ptr_checkbox;
     gboolean is_active;
 
     TRACE ("enters quick_message");
 
-    dialog = gtk_message_dialog_new (NULL,
+    ptr_dialog = gtk_message_dialog_new (NULL,
                                   0, /* GTK_DIALOG_DESTROY_WITH_PARENT */
                                   GTK_MESSAGE_INFO,
                                   GTK_BUTTONS_CLOSE,
-                                  message, NULL);
+                                  str_message, NULL);
 
-    gtk_window_set_title(GTK_WINDOW(dialog), _("Sensors Plugin"));
+    gtk_window_set_title(GTK_WINDOW(ptr_dialog), _("Sensors Plugin"));
 
-    checkbox = gtk_check_button_new_with_mnemonic (checkboxtext);
+    ptr_checkbox = gtk_check_button_new_with_mnemonic (str_checkboxtext);
 
-    gtk_box_pack_start (GTK_BOX(GTK_DIALOG(dialog)->vbox), checkbox, FALSE, FALSE, 0);
-    gtk_widget_show(checkbox);
+    gtk_box_pack_start (GTK_BOX(GTK_DIALOG(ptr_dialog)->vbox), ptr_checkbox, FALSE, FALSE, 0);
+    gtk_widget_show(ptr_checkbox);
 
-    gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_dialog_run(GTK_DIALOG(ptr_dialog));
 
-    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(checkbox));
+    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(ptr_checkbox));
 
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy (ptr_dialog);
 
     TRACE ("leaves quick_message");
 
@@ -179,79 +184,81 @@ quick_message_with_checkbox (gchar *message, gchar *checkboxtext) {
 #endif
 
 
+/* -------------------------------------------------------------------------- */
 void
-quick_message (gchar *message)
+quick_message (gchar *str_message)
 {
 #if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
-    quick_message_notify (message);
+    quick_message_notify (str_message);
 #else
-    quick_message_dialog (message);
+    quick_message_dialog (str_message);
 #endif
 }
 
 
 #ifdef HAVE_NETCAT
+/* -------------------------------------------------------------------------- */
 void
-read_disks_netcat (t_chip *chip)
+read_disks_netcat (t_chip *ptr_chip)
 {
-    char reply[REPLY_MAX_SIZE], *tmp, *tmp2, *tmp3;
+    char str_reply[REPLY_MAX_SIZE], *str_tmp, *str_tmp2, *str_tmp3;
     int result;
 
-    t_chipfeature *cf;
+    t_chipfeature *ptr_chipfeature;
 
-    bzero(&reply, REPLY_MAX_SIZE);
-    result = get_hddtemp_d_str(reply, REPLY_MAX_SIZE);
-    DBG ("reply=%s with result=%d\n", reply, (int) result);
+    bzero(&str_reply, REPLY_MAX_SIZE);
+    result = get_hddtemp_d_str(str_reply, REPLY_MAX_SIZE);
+    DBG ("reply=%s with result=%d\n", str_reply, (int) result);
     if (result==-1)
     {
       return;
     }
 
-    tmp = str_split (reply, DOUBLE_DELIMITER);
+    str_tmp = str_split (str_reply, DOUBLE_DELIMITER);
     do {
-        //g_printf ("Found token: %s\n", tmp);
-        cf = g_new0(t_chipfeature, 1);
+        ptr_chipfeature = g_new0(t_chipfeature, 1);
 
-        tmp2 = g_strdup (tmp);
-        tmp3 = strtok (tmp2, SINGLE_DELIMITER);
-        cf->devicename = g_strdup(tmp3);
-        tmp3 = strtok (NULL, SINGLE_DELIMITER);
-        cf->name = g_strdup(tmp3);
+        str_tmp2 = g_strdup (str_tmp);
+        str_tmp3 = strtok (str_tmp2, SINGLE_DELIMITER);
+        ptr_chipfeature->devicename = g_strdup(str_tmp3);
+        str_tmp3 = strtok (NULL, SINGLE_DELIMITER);
+        ptr_chipfeature->name = g_strdup(str_tmp3);
 
-        g_ptr_array_add(chip->chip_features, cf);
-        chip->num_features++;
+        g_ptr_array_add(ptr_chip->chip_features, ptr_chipfeature);
+        ptr_chip->num_features++;
 
-        g_free (tmp2);
+        g_free (str_tmp2);
     }
-    while ( (tmp = str_split(NULL, DOUBLE_DELIMITER)) );
+    while ( (str_tmp = str_split(NULL, DOUBLE_DELIMITER)) );
 }
 #else
+/* -------------------------------------------------------------------------- */
 void
-read_disks_fallback (t_chip *chip)
+read_disks_fallback (t_chip *ptr_chip)
 {
-    GError *error;
-    GDir *gdir;
-    t_chipfeature *chipfeature;
-    const gchar* dirname;
+    GError *ptr_error;
+    GDir *ptr_dir;
+    t_chipfeature *ptr_chipfeature;
+    const gchar* str_devicename;
 
     TRACE ("enters read_disks_fallback");
 
     /* read from /proc/ide */
-    error = NULL;
-    gdir = g_dir_open ("/proc/ide/", 0, &error);
+    ptr_error = NULL;
+    ptr_dir = g_dir_open ("/proc/ide/", 0, &ptr_error);
 
-    while ( (dirname = g_dir_read_name (gdir))!=NULL ) {
-        if ( strncmp (dirname, "hd", 2)==0 || strncmp (dirname, "sd", 2)==0) {
-            /* TODO: look, if /dev/dirname exists? */
-            chipfeature = g_new0 (t_chipfeature, 1);
-            chipfeature->devicename = g_strconcat ("/dev/", dirname, NULL);
-            chipfeature->name = g_strdup(chipfeature->devicename);
-            g_ptr_array_add (chip->chip_features, chipfeature);
-            chip->num_features++;
+    while ( (str_devicename = g_dir_read_name (ptr_dir))!=NULL ) {
+        if ( strncmp (str_devicename, "hd", 2)==0 || strncmp (str_devicename, "sd", 2)==0) {
+            /* TODO: look whether /dev/str_devicename exists? */
+            ptr_chipfeature = g_new0 (t_chipfeature, 1);
+            ptr_chipfeature->devicename = g_strconcat ("/dev/", str_devicename, NULL);
+            ptr_chipfeature->name = g_strdup(ptr_chipfeature->devicename);
+            g_ptr_array_add (ptr_chip->chip_features, ptr_chipfeature);
+            ptr_chip->num_features++;
         }
     }
 
-    g_dir_close (gdir);
+    g_dir_close (ptr_dir);
 
     /* FIXME: read SCSI info from where? SATA?  */
 
@@ -259,72 +266,73 @@ read_disks_fallback (t_chip *chip)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
-read_disks_linux26 (t_chip *chip)
+read_disks_linux26 (t_chip *ptr_chip)
 {
-    GDir *gdir;
-    t_chipfeature *chipfeature;
-    const gchar* dirname;
+    GDir *ptr_dir;
+    t_chipfeature *ptr_chipfeature;
+    const gchar* str_devicename;
 
     TRACE ("enters read_disks_linux26");
 
     /* read from /sys/block */
-    gdir = g_dir_open ("/sys/block/", 0, NULL);
-    while ( (dirname = g_dir_read_name (gdir))!=NULL ) {
-        /* if ( strncmp (dirname, "ram", 3)!=0 &&
-             strncmp (dirname, "loop", 4)!=0 &&
-             strncmp (dirname, "md", 2)!=0 &&
-             strncmp (dirname, "fd", 2)!=0 &&
-             strncmp (dirname, "mmc", 3)!=0 &&
-             strncmp (dirname, "dm-", 3)!=0 ) { */
-            if ( strncmp (dirname, "hd", 2)==0 ||
-                            strncmp (dirname, "sd", 2)==0 ) {
-            /* TODO: look, if /dev/dirname exists? */
-            chipfeature = g_new0 (t_chipfeature, 1);
-            chipfeature->devicename = g_strconcat ("/dev/", dirname, NULL); /* /proc/ide/hda/model ?? */
-            chipfeature->name = g_strdup(chipfeature->devicename);
-            g_ptr_array_add (chip->chip_features, chipfeature);
-            chip->num_features++;
+    ptr_dir = g_dir_open ("/sys/block/", 0, NULL);
+    while ( (str_devicename = g_dir_read_name (ptr_dir))!=NULL ) {
+        /* if ( strncmp (str_devicename, "ram", 3)!=0 &&
+             strncmp (str_devicename, "loop", 4)!=0 &&
+             strncmp (str_devicename, "md", 2)!=0 &&
+             strncmp (str_devicename, "fd", 2)!=0 &&
+             strncmp (str_devicename, "mmc", 3)!=0 &&
+             strncmp (str_devicename, "dm-", 3)!=0 ) { */
+        if ( strncmp (str_devicename, "hd", 2)==0 ||
+              strncmp (str_devicename, "sd", 2)==0 ) {
+            /* TODO: look whether /dev/str_devicename exists? */
+            ptr_chipfeature = g_new0 (t_chipfeature, 1);
+            ptr_chipfeature->devicename = g_strconcat ("/dev/", str_devicename, NULL); /* /proc/ide/hda/model ?? */
+            ptr_chipfeature->name = g_strdup(ptr_chipfeature->devicename);
+            g_ptr_array_add (ptr_chip->chip_features, ptr_chipfeature);
+            ptr_chip->num_features++;
         }
     }
 
-    g_dir_close (gdir);
+    g_dir_close (ptr_dir);
 
     TRACE ("leaves read_disks_linux26");
 }
 #endif
 
 
+/* -------------------------------------------------------------------------- */
 void
-remove_unmonitored_drives (t_chip *chip, gboolean *suppressmessage)
+remove_unmonitored_drives (t_chip *ptr_chip, gboolean *suppressmessage)
 {
-    int i, val_disk_temperature;
+    int idx_features, val_disk_temperature;
     t_chipfeature *ptr_chipfeature;
 
     TRACE ("enters remove_unmonitored_drives");
 
-    for (i=0; i<chip->num_features; i++)
+    for (idx_features=0; idx_features<ptr_chip->num_features; idx_features++)
     {
-        ptr_chipfeature = g_ptr_array_index (chip->chip_features, i);
+        ptr_chipfeature = g_ptr_array_index (ptr_chip->chip_features, idx_features);
         val_disk_temperature = get_hddtemp_value (ptr_chipfeature->devicename, suppressmessage);
         if (val_disk_temperature == NO_VALID_HDDTEMP_PROGRAM)
         {
             DBG ("removing single disk");
             free_chipfeature ( (gpointer) ptr_chipfeature, NULL);
-            g_ptr_array_remove_index (chip->chip_features, i);
-            i--;
-            chip->num_features--;
+            g_ptr_array_remove_index (ptr_chip->chip_features, idx_features);
+            idx_features--;
+            ptr_chip->num_features--;
         }
         else if (val_disk_temperature == NO_VALID_TEMPERATURE_VALUE)
         {
-            for (i=0; i < chip->num_features; i++) {
-                DBG ("remove %d\n", i);
-                ptr_chipfeature = g_ptr_array_index (chip->chip_features, i);
+            for (idx_features=0; idx_features < ptr_chip->num_features; idx_features++) {
+                DBG ("remove %d\n", idx_features);
+                ptr_chipfeature = g_ptr_array_index (ptr_chip->chip_features, idx_features);
                 free_chipfeature ( (gpointer) ptr_chipfeature, NULL);
             }
-            g_ptr_array_free (chip->chip_features, TRUE);
-            // chip->chip_features = g_ptr_array_new();
-            chip->num_features=0;
+            g_ptr_array_free (ptr_chip->chip_features, TRUE);
+            ptr_chip->num_features=0;
             DBG ("Returning because of bad hddtemp.\n");
             return;
         }
@@ -334,27 +342,24 @@ remove_unmonitored_drives (t_chip *chip, gboolean *suppressmessage)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
-populate_detected_drives (t_chip *chip)
+populate_detected_drives (t_chip *ptr_chip)
 {
     int idx_disks;
-    /* double value; */
     t_chipfeature *ptr_chipfeature;
 
     TRACE ("enters populate_detected_drives");
 
-    //chip->sensorId = g_strdup(_("Hard disks"));
-
-    for (idx_disks=0; idx_disks < chip->num_features; idx_disks++)
+    for (idx_disks=0; idx_disks < ptr_chip->num_features; idx_disks++)
     {
-       ptr_chipfeature = g_ptr_array_index (chip->chip_features, idx_disks);
+       ptr_chipfeature = g_ptr_array_index (ptr_chip->chip_features, idx_disks);
        g_assert (ptr_chipfeature!=NULL);
 
        ptr_chipfeature->address = idx_disks;
 
        ptr_chipfeature->color = g_strdup("#B000B0");
        ptr_chipfeature->valid = TRUE;
-       //ptr_chipfeature->formatted_value = g_strdup ("0.0"); /* _printf("%+5.1f", 0.0); */
        ptr_chipfeature->raw_value = 0.0;
 
        ptr_chipfeature->class = TEMPERATURE;
@@ -368,130 +373,127 @@ populate_detected_drives (t_chip *chip)
 }
 
 
+/* -------------------------------------------------------------------------- */
 int
-initialize_hddtemp (GPtrArray *chips, gboolean *suppressmessage)
+initialize_hddtemp (GPtrArray *arr_ptr_chips, gboolean *suppressmessage)
 {
 #ifndef HAVE_NETCAT
-    int generation, major, result;
-    struct utsname *p_uname = NULL;
+    int generation_linuxkernel, majorversion_linuxkernel;
+    struct utsname *ptr_unixname = NULL;
 #endif
-    int retval;
-    t_chip *chip;
+    int result;
+    t_chip *ptr_chip;
 
-    g_assert (chips!=NULL);
+    g_assert (arr_ptr_chips!=NULL);
 
     TRACE ("enters initialize_hddtemp");
 
-    chip = g_new0 (t_chip, 1);
+    ptr_chip = g_new0 (t_chip, 1);
 
-/*    chip->chip_name = (const sensors_chip_name *)
-            ( _("Hard disks"), 0, 0, _("Hard disks") ); */
-
-    chip->chip_features = g_ptr_array_new ();
-    chip->num_features = 0;
-    chip->description = g_strdup(_("S.M.A.R.T. harddisk temperatures"));
-    chip->name = g_strdup(_("Hard disks"));
-    chip->sensorId = g_strdup("Hard disks");
-    chip->type = HDD;
+    ptr_chip->chip_features = g_ptr_array_new ();
+    ptr_chip->num_features = 0;
+    ptr_chip->description = g_strdup(_("S.M.A.R.T. harddisk temperatures"));
+    ptr_chip->name = g_strdup(_("Hard disks"));
+    ptr_chip->sensorId = g_strdup("Hard disks");
+    ptr_chip->type = HDD;
 #ifdef HAVE_NETCAT
-    read_disks_netcat (chip);
+    read_disks_netcat (ptr_chip);
 #else
-    p_uname = (struct utsname *) malloc (sizeof(struct utsname));
-    result =  uname (p_uname);
+    ptr_unixname = (struct utsname *) malloc (sizeof(struct utsname));
+    result = uname (ptr_unixname);
     if (result!=0) {
-        g_free(p_uname);
+        g_free(ptr_unixname);
         return -1;
     }
 
-    generation = atoi ( p_uname->release ); /* this might cause trouble on */
-    major = atoi ( p_uname->release+2 );      /* other systems than Linux! */
+    generation_linuxkernel = atoi ( ptr_unixname->release ); /* this might cause trouble on */
+    majorversion_linuxkernel = atoi ( ptr_unixname->release+2 );      /* other systems than Linux! */
                 /* actually, wanted to use build time configuration therefore */
 
     /* Note: This is actually supposed to be carried out by ifdef HAVE_LINUX
      and major/minor number stuff from compile time*/
 
-    if (strcmp(p_uname->sysname, "Linux")==0 && (generation>=3 || (generation==2 && major>=5)))
-        read_disks_linux26 (chip);
+    if (strcmp(ptr_unixname->sysname, "Linux")==0 && (generation_linuxkernel>=3 || (generation_linuxkernel==2 && majorversion_linuxkernel>=5)))
+        read_disks_linux26 (ptr_chip);
     else
-        read_disks_fallback (chip); /* hopefully, that's a safe variant */
+        read_disks_fallback (ptr_chip); /* hopefully, that's a safe variant */
 
-    g_free(p_uname);
+    g_free(ptr_unixname);
 #endif
 
+    remove_unmonitored_drives (ptr_chip, suppressmessage);
+    DBG  ("numfeatures=%d\n", ptr_chip->num_features);
+    if ( ptr_chip->num_features>0 ) {  /* if (1) */
 
-    remove_unmonitored_drives (chip, suppressmessage);
-    DBG  ("numfeatures=%d\n", chip->num_features);
-    if ( chip->num_features>0 ) {  /* if (1) */
-
-        populate_detected_drives (chip);
-        g_ptr_array_add (chips, chip);
-        retval = 2;
+        populate_detected_drives (ptr_chip);
+        g_ptr_array_add (arr_ptr_chips, ptr_chip);
+        result = 2;
     }
     else {
-        retval = 0;
+        free_chip(ptr_chip, NULL);
+        result = 0;
     }
 
     TRACE ("leaves initialize_hddtemp");
 
-    return retval;
+    return result;
 }
 
 
-
+/* -------------------------------------------------------------------------- */
 int
 get_hddtemp_d_str (char *buffer, size_t bufsize)
 {
-    int sock;
-    struct sockaddr_in servername;
-    struct hostent *hostinfo;
-    int nbytes = 0, nchunk = 0;
+    int socket_number;
+    struct sockaddr_in sockaddr_hddtemplocalhost;
+    struct hostent *ptr_hostinfo;
+    int num_read_bytes_total = 0, num_read = 0;
 
     /* Create the socket. */
-    sock = socket(PF_INET, SOCK_STREAM, 0);
-    if (sock < 0) {
+    socket_number = socket(PF_INET, SOCK_STREAM, 0);
+    if (socket_number < 0) {
       return HDDTEMP_CONNECTION_FAILED;
     }
 
     /* Connect to the server. */
-    servername.sin_family = AF_INET;
-    servername.sin_port = htons(HDDTEMP_PORT);
-    hostinfo = gethostbyname("localhost");
-    if (hostinfo == NULL) {
-/*  fprintf (stderr, "Unknown host %s.\n", hostname);*/
+    sockaddr_hddtemplocalhost.sin_family = AF_INET;
+    sockaddr_hddtemplocalhost.sin_port = htons(HDDTEMP_PORT);
+    ptr_hostinfo = gethostbyname("localhost");
+    if (ptr_hostinfo == NULL) {
       return HDDTEMP_CONNECTION_FAILED;
     }
-    servername.sin_addr = *(struct in_addr *) hostinfo->h_addr;
+    sockaddr_hddtemplocalhost.sin_addr = *(struct in_addr *) ptr_hostinfo->h_addr;
 
-    if (connect (sock, (struct sockaddr *) &servername, sizeof (servername)) < 0) {
-/*  perror ("connect (client)");*/
+    if (connect (socket_number, (struct sockaddr *) &sockaddr_hddtemplocalhost, sizeof (sockaddr_hddtemplocalhost)) < 0) {
       return HDDTEMP_CONNECTION_FAILED;
     }
 
     /* Read data from server. */
     for (;;) {
-      nchunk = read(sock, buffer+nbytes, bufsize-nbytes-1);
-      if (nchunk < 0) {
+      num_read = read(socket_number, buffer+num_read_bytes_total, bufsize-num_read_bytes_total-1);
+      if (num_read < 0) {
           /* Read error. */
-    /*      perror ("read");*/
-          close (sock);
+          close (socket_number);
           return HDDTEMP_CONNECTION_FAILED;
-      } else if (nchunk == 0) {
+      } else if (num_read == 0) {
           /* End-of-file. */
           break;
       } else {
           /* Data read. */
-          nbytes += nchunk;
+          num_read_bytes_total += num_read;
       }
     }
 
-    buffer[nbytes] = 0;
-    close (sock);
-    return nbytes;
+    buffer[num_read_bytes_total] = 0;
+    close (socket_number);
+
+    return num_read_bytes_total;
 }
 
 
+/* -------------------------------------------------------------------------- */
 double
-get_hddtemp_value (char* disk, gboolean *suppressmessage)
+get_hddtemp_value (char* str_disk, gboolean *ptr_suppressmessage)
 {
     gchar *ptr_str_stdout=NULL, *ptr_str_stderr=NULL;
     gchar *ptr_str_hddtemp_call=NULL, *ptr_str_message=NULL;
@@ -505,20 +507,20 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
     GError *ptr_f_error=NULL;
 
 #ifdef HAVE_NETCAT
-    gchar *tmp, *tmp2, *tmp3;
+    gchar *str_tmp, *str_tmp2, *str_tmp3;
     char reply[REPLY_MAX_SIZE];
     int val_hddtemp_result;
 #endif
 
-    if (disk==NULL)
+    if (str_disk==NULL)
       return NO_VALID_TEMPERATURE_VALUE;
 
-    if (suppressmessage!=NULL)
-        f_nevershowagain = *suppressmessage;
+    if (ptr_suppressmessage!=NULL)
+        f_nevershowagain = *ptr_suppressmessage;
     else
         f_nevershowagain = FALSE;
 
-    TRACE ("enters get_hddtemp_value for %s with suppress=%d", disk, f_nevershowagain); /* *suppressmessage); */
+    TRACE ("enters get_hddtemp_value for %s with suppress=%d", str_disk, f_nevershowagain); /* *ptr_suppressmessage); */
 
 #ifdef HAVE_NETCAT
 
@@ -529,37 +531,36 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
       return NO_VALID_HDDTEMP_PROGRAM;
     }
 
-    tmp3 = "-255";
-    tmp = str_split (reply, DOUBLE_DELIMITER);
+    str_tmp3 = "-255";
+    str_tmp = str_split (reply, DOUBLE_DELIMITER);
     do {
-        //g_printf ("Found token: %s for disk %s\n", tmp, disk);
-        tmp2 = g_strdup (tmp);
-        tmp3 = strtok (tmp2, SINGLE_DELIMITER); // device name
-        if (strcmp(tmp3, disk)==0)
+        str_tmp2 = g_strdup (str_tmp);
+        str_tmp3 = strtok (str_tmp2, SINGLE_DELIMITER); // device name
+        if (strcmp(str_tmp3, str_disk)==0)
         {
             strtok(NULL, SINGLE_DELIMITER); // name
-            tmp3 = strdup(strtok(NULL, SINGLE_DELIMITER)); // value
+            str_tmp3 = strdup(strtok(NULL, SINGLE_DELIMITER)); // value
             exit_status = 0;
             ptr_f_error = NULL;
-            g_free (tmp2);
+            g_free (str_tmp2);
             break;
         }
-        g_free (tmp2);
+        g_free (str_tmp2);
     }
-    while ( (tmp = str_split(NULL, DOUBLE_DELIMITER)) );
+    while ( (str_tmp = str_split(NULL, DOUBLE_DELIMITER)) );
 
-    ptr_str_stdout = tmp3;
+    ptr_str_stdout = str_tmp3;
 
 #else
-    ptr_str_hddtemp_call = g_strdup_printf ( "%s -n -q %s", PATH_HDDTEMP, disk);
+    ptr_str_hddtemp_call = g_strdup_printf ( "%s -n -q %s", PATH_HDDTEMP, str_disk);
     f_result = g_spawn_command_line_sync ( (const gchar*) ptr_str_hddtemp_call,
             &ptr_str_stdout, &ptr_str_stderr, &exit_status, &ptr_f_error);
 #endif
 
-    DBG ("Exit code %d on %s with stdout of %s.\n", exit_status, disk, ptr_str_stdout);
+    DBG ("Exit code %d on %s with stdout of %s.\n", exit_status, str_disk, ptr_str_stdout);
 
     /* filter those with no sensors out */
-    if (exit_status==0 && strncmp(disk, "/dev/fd", 6)==0) { /* is returned for floppy disks */
+    if (exit_status==0 && strncmp(str_disk, "/dev/fd", 6)==0) { /* is returned for floppy disks */
         DBG("exit_status==0 && strncmp(disk, \"/dev/fd\", 6)==0");
         val_drive_temperature = NO_VALID_TEMPERATURE_VALUE;
     }
@@ -580,16 +581,14 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
                             PATH_HDDTEMP, ptr_str_hddtemp_call, ptr_str_stderr, exit_status);
 
 #if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
-            //ptr_str_message = g_strconcat(ptr_str_message, _("\nYou can disable these notifications in the settings dialog.\n");
             quick_message_notify (ptr_str_message);
-            //f_nevershowagain = FALSE;
 #else
             ptr_str_checkbutton = g_strdup(_("Suppress this message in future"));
             f_nevershowagain = quick_message_with_checkbox(ptr_str_message, ptr_str_checkbutton);
 #endif
 
-            if (suppressmessage!=NULL)
-                *suppressmessage = f_nevershowagain;
+            if (ptr_suppressmessage!=NULL)
+                *ptr_suppressmessage = f_nevershowagain;
         }
         else {
             DBG  ("Suppressing dialog with exit_code=256 or output on ptr_str_stderr");
@@ -606,14 +605,13 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
                                       " \"%s\":\n%s"), ptr_str_hddtemp_call, ptr_f_error->message);
 #if defined(HAVE_LIBNOTIFY4) || defined(HAVE_LIBNOTIFY7)
             quick_message_notify (ptr_str_message);
-            //f_nevershowagain = FALSE;
 #else
             ptr_str_checkbutton = g_strdup(_("Suppress this message in future"));
             f_nevershowagain = quick_message_with_checkbox (ptr_str_message, ptr_str_checkbutton);
 #endif
 
-            if (suppressmessage!=NULL)
-                *suppressmessage = f_nevershowagain;
+            if (ptr_suppressmessage!=NULL)
+                *ptr_suppressmessage = f_nevershowagain;
         }
         else {
             DBG  ("Suppressing dialog because of error in g_spawn_cl");
@@ -626,7 +624,8 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
         /* hddtemp does not return floating values, but only integer ones.
           So have an easier life with atoi.
           FIXME: Use strtod() instead?*/
-        if (0 == strcmp(ptr_str_stdout, "drive is sleeping"))
+        if ( 0 == strcmp(ptr_str_stdout, "drive is sleeping")
+          || 0 == strcmp(ptr_str_stdout, "SLP") )
             val_drive_temperature = HDDTEMP_DISK_SLEEPING;
         else
             val_drive_temperature = (double) (atoi ( (const char*) ptr_str_stdout) );
@@ -653,8 +652,9 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
 }
 
 
+/* -------------------------------------------------------------------------- */
 void
-refresh_hddtemp (gpointer chip_feature, gpointer data)
+refresh_hddtemp (gpointer chip_feature, gpointer ptr_sensors)
 {
     t_chipfeature *ptr_chipfeature;
     double val_drive_temperature;
@@ -665,9 +665,9 @@ refresh_hddtemp (gpointer chip_feature, gpointer data)
 
     TRACE ("enters refresh_hddtemp");
 
-    if (data != NULL)
+    if (ptr_sensors != NULL)
     {
-        ptr_sensors_plugin_data = (t_sensors *) data;
+        ptr_sensors_plugin_data = (t_sensors *) ptr_sensors;
         ptr_f_suppress = &(ptr_sensors_plugin_data->suppressmessage);
     }
 
@@ -675,24 +675,7 @@ refresh_hddtemp (gpointer chip_feature, gpointer data)
 
     val_drive_temperature = get_hddtemp_value (ptr_chipfeature->devicename, ptr_f_suppress);
 
-    //g_free (ptr_chipfeature->formatted_value);
-    //ptr_chipfeature->formatted_value = g_strdup_printf(_("%.1f °C"), val_drive_temperature);
     ptr_chipfeature->raw_value = val_drive_temperature;
 
     TRACE ("leaves refresh_hddtemp");
 }
-
-
-//void
-//free_hddtemp_chip (gpointer chip)
-//{
-    //t_chip *ptr_chip;
-
-    //ptr_chip = (t_chip *) chip;
-
-    ////if (ptr_chip->sensorId)
-        ////g_free (ptr_chip->sensorId);
-
-    ////if (ptr_chip->chip_name->)
-        ////g_free (ptr_chip->chip_name->);
-//}
