@@ -27,7 +27,7 @@
 
 /**
  * Populate the application's main window
- * @param sd: pointers to already filled sensors dialog structure
+ * @param ptr_sensorsdialog: pointers to already filled sensors dialog structure
  * @return newly allocated GtkWidget of main window
  */
-GtkWidget * create_main_window (t_sensors_dialog *sd);
+GtkWidget * create_main_window (t_sensors_dialog *ptr_sensorsdialog);
