@@ -1,6 +1,6 @@
-/* $Id$ */
-
-/*  Copyright 2008-2010 Fabian Nowak (timystery@arcor.de)
+/* File: main.c
+ *
+ *  Copyright 2008-2017 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -52,6 +52,10 @@ void print_usage (void);
 void print_version (void);
 t_sensors_dialog * initialize_sensors_structures (void);
 
+/* -------------------------------------------------------------------------- */
+/**
+ * Prints license information
+ */
 void
 print_license (void)
 {
@@ -64,6 +68,10 @@ print_license (void)
 }
 
 
+/* -------------------------------------------------------------------------- */
+/**
+ * Prints help/usage information
+ */
 void
 print_usage (void)
 {
@@ -71,8 +79,8 @@ print_usage (void)
                       "Displays information about your hardware sensors, ACPI "
                                             "status, harddisk temperatures and Nvidia GPU's temperature.\n"
                       "Synopsis: \n"
-                      "  xfce4-sensors options\n"
-                      "where options are one or more of the following:\n"
+                      "  xfce4-sensors [option]\n"
+                      "where [option] is one of the following:\n"
                       "  -h, --help    Print this help dialog.\n"
                       "  -l, --license Print license information.\n"
                       "  -V, --version Print version information.\n"
@@ -82,6 +90,10 @@ print_usage (void)
 }
 
 
+/* -------------------------------------------------------------------------- */
+/**
+ * Prints version information as requested by "xfce4-sensors -V"
+ */
 void
 print_version (void)
 {
@@ -89,6 +101,11 @@ print_version (void)
 }
 
 
+/* -------------------------------------------------------------------------- */
+/**
+ * Initializes the required sensor structures.
+ * @return pointer to newly allocated sensors dialog information
+ */
 t_sensors_dialog *
 initialize_sensors_structures (void)
 {
@@ -113,14 +130,12 @@ initialize_sensors_structures (void)
 }
 
 
-//static void
-//on_window_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
-//{
-  //DBG("on_window_destroy_event\n");
-    ///* do some cleaning in here rather than at the end of the program? */
-//}
-
-
+/* -------------------------------------------------------------------------- */
+/**
+ * Main routine.
+ * @param argc: number of arguments
+ * @param argv: array of strings passed as arguments
+ */
 int
 main (int argc, char **argv)
 {
@@ -151,6 +166,16 @@ main (int argc, char **argv)
     /* start the Gtk engine */
     gtk_init (&argc, &argv);
 
+    /* declare callback functions for libxfce4sensors */
+    adjustment_value_changed = &adjustment_value_changed_;
+    sensor_entry_changed = &sensor_entry_changed_;
+    list_cell_text_edited= &list_cell_text_edited_;
+    list_cell_toggle = &list_cell_toggle_;
+    list_cell_color_edited = &list_cell_color_edited_;
+    minimum_changed = &minimum_changed_;
+    maximum_changed = &maximum_changed_;
+    temperature_unit_change = &temperature_unit_change_;
+
     /* initialize sensor stuff */
     ptr_sensors_dialog = initialize_sensors_structures ();
 
@@ -166,16 +191,13 @@ main (int argc, char **argv)
     /* show window and run forever */
     gtk_widget_show_all(window); /* to make sure everything is shown */
     gtk_window_resize(GTK_WINDOW(window), 400, 500);
-    //gtk_widget_realize(sd->sensors->widget_sensors); /* without this call, the table will only be realized when the tab is shown and hence, toggled tachos are not drawn as they lack a drawable window. */
-
-    //g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(on_window_destroy_event), NULL);
 
     gtk_main();
 
-    gtk_widget_destroy(window);
-
     /* do the cleaning? */
     free_widgets(ptr_sensors_dialog); /* counterpart to init_widgets() inside create_main_window() */
+    gtk_widget_destroy(window);
+
     g_free (ptr_sensors_dialog->sensors);
     g_free (ptr_sensors_dialog);
 
